Welcome to fmu-config's documentation!
======================================


.. toctree::
   :maxdepth: 2

   installation
   yamlformat
   usage
   examples
   contributing

API
===

.. toctree::

   fmu.config/fmu.config

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
